@@ -1,7 +1,9 @@
-from base import Address, PhoneNumber, EmailAddress, WebAddress, Ref, QuickbooksManagedObject, \
+from six import python_2_unicode_compatible
+from .base import Address, PhoneNumber, EmailAddress, WebAddress, Ref, QuickbooksManagedObject, \
     QuickbooksTransactionEntity
 
 
+@python_2_unicode_compatible
 class Customer(QuickbooksManagedObject, QuickbooksTransactionEntity):
     """
     QBO definition: A customer is a consumer of the service or product that your business offers. The Customer object
@@ -55,6 +57,7 @@ class Customer(QuickbooksManagedObject, QuickbooksTransactionEntity):
         self.ResaleNum = ""
         self.Level = 0
         self.OpenBalanceDate = ""
+        self.PrimaryTaxIdentifier = ""
 
         self.BillAddr = None
         self.ShipAddr = None
@@ -70,7 +73,7 @@ class Customer(QuickbooksManagedObject, QuickbooksTransactionEntity):
         self.ParentRef = None
         self.ARAccountRef = None
 
-    def __unicode__(self):
+    def __str__(self):
         return self.DisplayName
 
     def to_ref(self):
